@@ -479,7 +479,6 @@ struct hid_device_info  HID_API_EXPORT *hid_enumerate(unsigned short vendor_id,
 
 			/* Fill out the record */
 			cur_dev->next = NULL;
-			len = make_path(dev, cbuf, sizeof(cbuf));
 			cur_dev->path = strdup(cbuf);
 
 			/* Serial Number */
@@ -502,9 +501,7 @@ struct hid_device_info  HID_API_EXPORT *hid_enumerate(unsigned short vendor_id,
 			/* Interface Number (Unsupported on Mac)*/
 			cur_dev->interface_number = -1;
 
-			CFDataRef ref;
 			CFStringRef prop = CFSTR(kIOHIDReportDescriptorKey);
-			ref = IOHIDDeviceGetProperty(dev, prop);
 			//hid_get_report_descriptor(dev,buf, BUF_LEN);
 		}
 	}
