@@ -58,36 +58,32 @@ namespace {
 
 spin_lock rt_pool_guard;
 
-inline Node * as_Node(server_node * node)
-{
+inline Node* as_Node(server_node* node) {
     if (node == nullptr)
         return nullptr;
 
     // hack!!! we only assume that the 32bit integer mID member can be accessed via Node
     if (node->is_synth()) {
-        sc_synth * s = static_cast<sc_synth*>(node);
+        sc_synth* s = static_cast<sc_synth*>(node);
         return &s->mNode;
     } else {
-        void * nodePointer = &node->node_id;
+        void* nodePointer = &node->node_id;
         return (Node*)nodePointer;
     }
 }
 
-void pause_node(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void pause_node(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_pause_node(node);
 }
 
-void free_node(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 }
 
-void free_node_and_preceding(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_preceding(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -96,14 +92,13 @@ void free_node_and_preceding(Unit * unit)
         return;
     }
 
-    server_node * preceding = node->previous_node();
+    server_node* preceding = node->previous_node();
     if (preceding)
         sc_factory->add_done_node(preceding);
 }
 
-void free_node_and_pause_preceding(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_pause_preceding(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -112,14 +107,13 @@ void free_node_and_pause_preceding(Unit * unit)
         return;
     }
 
-    server_node * preceding = node->previous_node();
+    server_node* preceding = node->previous_node();
     if (preceding)
         sc_factory->add_pause_node(preceding);
 }
 
-void free_node_and_preceding_children(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_preceding_children(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -128,21 +122,20 @@ void free_node_and_preceding_children(Unit * unit)
         return;
     }
 
-    server_node * preceding = node->previous_node();
+    server_node* preceding = node->previous_node();
     if (!preceding)
         return;
     if (preceding->is_synth())
         sc_factory->add_done_node(preceding);
     else {
-        abstract_group * preceding_group = static_cast<abstract_group*>(preceding);
+        abstract_group* preceding_group = static_cast<abstract_group*>(preceding);
         sc_factory->add_freeAll_node(preceding_group);
     }
 }
 
 
-void free_node_and_preceding_deep(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_preceding_deep(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -150,20 +143,19 @@ void free_node_and_preceding_deep(Unit * unit)
         return;
     }
 
-    server_node * preceding = node->previous_node();
+    server_node* preceding = node->previous_node();
     if (!preceding)
         return;
     if (preceding->is_synth())
         sc_factory->add_done_node(preceding);
     else {
-        abstract_group * preceding_group = static_cast<abstract_group*>(preceding);
+        abstract_group* preceding_group = static_cast<abstract_group*>(preceding);
         sc_factory->add_freeDeep_node(preceding_group);
     }
 }
 
-void free_node_and_all_preceding(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_all_preceding(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -172,7 +164,7 @@ void free_node_and_all_preceding(Unit * unit)
         return;
     }
 
-    for(;;) {
+    for (;;) {
         node = node->previous_node();
         if (node)
             sc_factory->add_done_node(node);
@@ -181,9 +173,8 @@ void free_node_and_all_preceding(Unit * unit)
     }
 }
 
-void free_node_and_following(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_following(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -192,14 +183,13 @@ void free_node_and_following(Unit * unit)
         return;
     }
 
-    server_node * next = node->next_node();
+    server_node* next = node->next_node();
     if (next)
         sc_factory->add_done_node(next);
 }
 
-void free_node_and_pause_following(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_pause_following(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -208,30 +198,13 @@ void free_node_and_pause_following(Unit * unit)
         return;
     }
 
-    server_node * next = node->next_node();
+    server_node* next = node->next_node();
     if (next)
         sc_factory->add_pause_node(next);
 }
 
-void free_node_and_resume_following(Unit * unit)
-{
-	server_node * node = static_cast<sc_synth*>(unit->mParent);
-	sc_factory->add_done_node(node);
-
-	if (node->get_parent()->is_parallel()) {
-		spin_lock::scoped_lock lock(log_guard);
-		log("parallel groups have no notion of following nodes\n");
-		return;
-	}
-	
-	server_node * next = node->next_node();
-	if (next)
-		sc_factory->add_resume_node(next);
-}
-	
-void free_node_and_following_children(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_resume_following(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -240,20 +213,34 @@ void free_node_and_following_children(Unit * unit)
         return;
     }
 
-    server_node * following = node->previous_node();
+    server_node* next = node->next_node();
+    if (next)
+        sc_factory->add_resume_node(next);
+}
+
+void free_node_and_following_children(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
+    sc_factory->add_done_node(node);
+
+    if (node->get_parent()->is_parallel()) {
+        spin_lock::scoped_lock lock(log_guard);
+        log("parallel groups have no notion of following nodes\n");
+        return;
+    }
+
+    server_node* following = node->previous_node();
     if (!following)
         return;
     if (following->is_synth())
         sc_factory->add_done_node(following);
     else {
-        abstract_group * following_group = static_cast<abstract_group*>(following);
+        abstract_group* following_group = static_cast<abstract_group*>(following);
         sc_factory->add_freeAll_node(following_group);
     }
 }
 
-void free_node_and_following_deep(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_following_deep(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -262,20 +249,19 @@ void free_node_and_following_deep(Unit * unit)
         return;
     }
 
-    server_node * following = node->previous_node();
+    server_node* following = node->previous_node();
     if (!following)
         return;
     if (following->is_synth())
         sc_factory->add_done_node(following);
     else {
-        abstract_group * following_group = static_cast<abstract_group*>(following);
+        abstract_group* following_group = static_cast<abstract_group*>(following);
         sc_factory->add_freeDeep_node(following_group);
     }
 }
 
-void free_node_and_all_following(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
+void free_node_and_all_following(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
     sc_factory->add_done_node(node);
 
     if (node->get_parent()->is_parallel()) {
@@ -284,7 +270,7 @@ void free_node_and_all_following(Unit * unit)
         return;
     }
 
-    for(;;) {
+    for (;;) {
         node = node->previous_node();
         if (node)
             sc_factory->add_done_node(node);
@@ -293,49 +279,43 @@ void free_node_and_all_following(Unit * unit)
     }
 }
 
-void free_group_members(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
-    abstract_group * group = const_cast<abstract_group*>(node->get_parent());
+void free_group_members(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
+    abstract_group* group = const_cast<abstract_group*>(node->get_parent());
 
     sc_factory->add_freeAll_node(group);
 }
 
-void free_parent_group(Unit * unit)
-{
-    server_node * node = static_cast<sc_synth*>(unit->mParent);
-    abstract_group * group = const_cast<abstract_group*>(node->get_parent());
+void free_parent_group(Unit* unit) {
+    server_node* node = static_cast<sc_synth*>(unit->mParent);
+    abstract_group* group = const_cast<abstract_group*>(node->get_parent());
     sc_factory->add_done_node(group);
 }
 
-bool get_scope_buffer(World *inWorld, int index, int channels, int maxFrames, ScopeBufferHnd &hnd)
-{
-    scope_buffer_writer writer = instance->get_scope_buffer_writer( index, channels, maxFrames );
+bool get_scope_buffer(World* inWorld, int index, int channels, int maxFrames, ScopeBufferHnd& hnd) {
+    scope_buffer_writer writer = instance->get_scope_buffer_writer(index, channels, maxFrames);
 
-    if( writer.valid() ) {
+    if (writer.valid()) {
         hnd.internalData = writer.buffer;
         hnd.data = writer.data();
         hnd.channels = channels;
         hnd.maxFrames = maxFrames;
         return true;
-    }
-    else {
+    } else {
         hnd.internalData = nullptr;
         return false;
     }
 }
 
-void push_scope_buffer(World *inWorld, ScopeBufferHnd &hnd, int frames)
-{
+void push_scope_buffer(World* inWorld, ScopeBufferHnd& hnd, int frames) {
     scope_buffer_writer writer(reinterpret_cast<scope_buffer*>(hnd.internalData));
     writer.push(frames);
     hnd.data = writer.data();
 }
 
-void release_scope_buffer(World *inWorld, ScopeBufferHnd &hnd)
-{
+void release_scope_buffer(World* inWorld, ScopeBufferHnd& hnd) {
     scope_buffer_writer writer(reinterpret_cast<scope_buffer*>(hnd.internalData));
-    instance->release_scope_buffer_writer( writer );
+    instance->release_scope_buffer_writer(writer);
 }
 
 } /* namespace */
@@ -343,43 +323,34 @@ void release_scope_buffer(World *inWorld, ScopeBufferHnd &hnd)
 
 extern "C" {
 
-bool define_unit(const char *inUnitClassName, size_t inAllocSize,
-                 UnitCtorFunc inCtor, UnitDtorFunc inDtor, uint32 inFlags)
-{
+bool define_unit(const char* inUnitClassName, size_t inAllocSize, UnitCtorFunc inCtor, UnitDtorFunc inDtor,
+                 uint32 inFlags) {
     try {
         nova::sc_factory->register_ugen(inUnitClassName, inAllocSize, inCtor, inDtor, inFlags);
         return true;
-    }
-    catch(...)
-    {
+    } catch (...) {
         return false;
     }
 }
 
-bool define_bufgen(const char * name, BufGenFunc func)
-{
+bool define_bufgen(const char* name, BufGenFunc func) {
     try {
         nova::sc_factory->register_bufgen(name, func);
         return true;
-    }
-    catch(...)
-    {
+    } catch (...) {
         return false;
     }
 }
 
-bool define_unitcmd(const char * unitClassName, const char * cmdName, UnitCmdFunc inFunc)
-{
+bool define_unitcmd(const char* unitClassName, const char* cmdName, UnitCmdFunc inFunc) {
     return nova::sc_factory->register_ugen_command_function(unitClassName, cmdName, inFunc);
 }
 
-bool define_plugincmd(const char * name, PlugInCmdFunc func, void * user_data)
-{
+bool define_plugincmd(const char* name, PlugInCmdFunc func, void* user_data) {
     return nova::sc_factory->register_cmd_plugin(name, func, user_data);
 }
 
-void * rt_alloc(World * dummy, size_t size)
-{
+void* rt_alloc(World* dummy, size_t size) {
     nova::spin_lock::scoped_lock lock(nova::rt_pool_guard);
     if (size)
         return nova::rt_pool.malloc(size);
@@ -387,87 +358,63 @@ void * rt_alloc(World * dummy, size_t size)
         return nullptr;
 }
 
-void * rt_realloc(World * dummy, void * ptr, size_t size)
-{
+void* rt_realloc(World* dummy, void* ptr, size_t size) {
     nova::spin_lock::scoped_lock lock(nova::rt_pool_guard);
     return nova::rt_pool.realloc(ptr, size);
 }
 
-void rt_free(World * dummy, void * ptr)
-{
+void rt_free(World* dummy, void* ptr) {
     nova::spin_lock::scoped_lock lock(nova::rt_pool_guard);
     if (ptr)
         nova::rt_pool.free(ptr);
 }
 
-void * nrt_alloc(size_t size)
-{
-    return malloc(size);
-}
+void* nrt_alloc(size_t size) { return malloc(size); }
 
-void * nrt_realloc(void * ptr, size_t size)
-{
-    return realloc(ptr, size);
-}
+void* nrt_realloc(void* ptr, size_t size) { return realloc(ptr, size); }
 
-void nrt_free(void * ptr)
-{
-    free(ptr);
-}
+void nrt_free(void* ptr) { free(ptr); }
 
-void * nrt_alloc_2(World * dummy, size_t size)
-{
-    return malloc(size);
-}
+void* nrt_alloc_2(World* dummy, size_t size) { return malloc(size); }
 
-void * nrt_realloc_2(World * dummy, void * ptr, size_t size)
-{
-    return realloc(ptr, size);
-}
+void* nrt_realloc_2(World* dummy, void* ptr, size_t size) { return realloc(ptr, size); }
 
-void nrt_free_2(World * dummy, void * ptr)
-{
-    free(ptr);
-}
+void nrt_free_2(World* dummy, void* ptr) { free(ptr); }
 
 
-
-void clear_outputs(Unit *unit, int samples)
-{
+void clear_outputs(Unit* unit, int samples) {
     const uint32_t outputs = unit->mNumOutputs;
 
-    if( (samples & 63) == 0 ) {
+    if ((samples & 63) == 0) {
         const uint32_t loops = samples / 64;
 
-        for( int i=0; i != outputs; ++i ) {
-            float * buffer = unit->mOutBuf[i];
-            for( int loop = 0; loop != loops; ++loop ) {
-                nova::zerovec_simd<64>( buffer + loop * 64 );
+        for (int i = 0; i != outputs; ++i) {
+            float* buffer = unit->mOutBuf[i];
+            for (int loop = 0; loop != loops; ++loop) {
+                nova::zerovec_simd<64>(buffer + loop * 64);
             }
         }
         return;
     }
 
-    if( (samples & 15) == 0 ) {
-        for( int i=0; i != outputs; ++i )
+    if ((samples & 15) == 0) {
+        for (int i = 0; i != outputs; ++i)
             nova::zerovec_simd(unit->mOutBuf[i], samples);
         return;
     }
 
-    for( int i=0; i != outputs; ++i )
-      nova::zerovec(unit->mOutBuf[i], samples);
+    for (int i = 0; i != outputs; ++i)
+        nova::zerovec(unit->mOutBuf[i], samples);
 }
 
-void node_end(struct Node * node)
-{
-    nova::server_node * s = nova::instance->find_node(node->mID);
+void node_end(struct Node* node) {
+    nova::server_node* s = nova::instance->find_node(node->mID);
     nova::sc_factory->add_done_node(s);
 }
 
-void node_set_run(struct Node * node, int run)
-{
+void node_set_run(struct Node* node, int run) {
     using namespace nova;
-    server_node * s = instance->find_node(node->mID);
+    server_node* s = instance->find_node(node->mID);
 
     if (run == 0)
         sc_factory->add_pause_node(s);
@@ -476,8 +423,7 @@ void node_set_run(struct Node * node, int run)
 }
 
 
-int print(const char *fmt, ...)
-{
+int print(const char* fmt, ...) {
     va_list vargs;
     va_start(vargs, fmt);
 
@@ -490,10 +436,9 @@ int print(const char *fmt, ...)
 }
 
 /* todo: we need to implement most of the done actions */
-void done_action(int done_action, struct Unit *unit)
-{
+void done_action(int done_action, struct Unit* unit) {
     using namespace nova;
-    switch(done_action) {
+    switch (done_action) {
     case 0:
         // do nothing when the UGen is finished
         return;
@@ -528,12 +473,12 @@ void done_action(int done_action, struct Unit *unit)
         return;
 
     case 7:
-        //free this synth and all preceding nodes in this group
+        // free this synth and all preceding nodes in this group
         nova::free_node_and_all_preceding(unit);
         return;
 
     case 8:
-        //free this synth and all following nodes in this group
+        // free this synth and all following nodes in this group
         nova::free_node_and_all_following(unit);
         return;
 
@@ -566,78 +511,64 @@ void done_action(int done_action, struct Unit *unit)
         // free the enclosing group and all nodes within it (including this synth)
         nova::free_parent_group(unit);
         return;
-	
-	case 15:
-		// free this synth and resume the following node
-		nova::free_node_and_resume_following(unit);
-		return;
+
+    case 15:
+        // free this synth and resume the following node
+        nova::free_node_and_resume_following(unit);
+        return;
 
     default:
         return;
     }
 }
 
-int buf_alloc(SndBuf * buf, int channels, int frames, double samplerate)
-{
+int buf_alloc(SndBuf* buf, int channels, int frames, double samplerate) {
     try {
         nova::sc_factory->allocate_buffer(buf, channels, frames, samplerate);
         return kSCErr_None;
-    } catch(std::exception const & e) {
+    } catch (std::exception const& e) {
         std::cout << e.what() << std::endl;
         return kSCErr_Failed;
     }
 }
 
-void send_trigger(Node * unit, int trigger_id, float value)
-{
+void send_trigger(Node* unit, int trigger_id, float value) {
     nova::instance->send_trigger(unit->mID, trigger_id, value);
 }
 
-void world_lock(World *world)
-{
-    reinterpret_cast<SC_Lock*>(world->mNRTLock)->lock();
-}
+void world_lock(World* world) { reinterpret_cast<SC_Lock*>(world->mNRTLock)->lock(); }
 
-void world_unlock(World *world)
-{
-    reinterpret_cast<SC_Lock*>(world->mNRTLock)->unlock();
-}
+void world_unlock(World* world) { reinterpret_cast<SC_Lock*>(world->mNRTLock)->unlock(); }
 
-Node * get_node(World *world, int id)
-{
-    nova::server_node * node = nova::instance->find_node(id);
+Node* get_node(World* world, int id) {
+    nova::server_node* node = nova::instance->find_node(id);
     return nova::as_Node(node);
 }
 
-void send_node_reply(Node* node, int reply_id, const char* command_name, int argument_count, const float* values)
-{
+void send_node_reply(Node* node, int reply_id, const char* command_name, int argument_count, const float* values) {
     if (!nova::sc_factory->world.mRealTime)
         return;
 
     nova::instance->send_node_reply(node->mID, reply_id, command_name, argument_count, values);
 }
 
-int do_asynchronous_command(World *inWorld, void* replyAddr, const char* cmdName, void *cmdData,
-                            AsyncStageFn stage2, // stage2 is non real time
-                            AsyncStageFn stage3, // stage3 is real time - completion msg performed if stage3 returns true
-                            AsyncStageFn stage4, // stage4 is non real time - sends done if stage4 returns true
-                            AsyncFreeFn cleanup,
-                            int completionMsgSize, void* completionMsgData)
-{
-    nova::instance->do_asynchronous_command(inWorld, replyAddr, cmdName, cmdData,
-                                            stage2, stage3, stage4, cleanup,
+int do_asynchronous_command(
+    World* inWorld, void* replyAddr, const char* cmdName, void* cmdData,
+    AsyncStageFn stage2, // stage2 is non real time
+    AsyncStageFn stage3, // stage3 is real time - completion msg performed if stage3 returns true
+    AsyncStageFn stage4, // stage4 is non real time - sends done if stage4 returns true
+    AsyncFreeFn cleanup, int completionMsgSize, void* completionMsgData) {
+    nova::instance->do_asynchronous_command(inWorld, replyAddr, cmdName, cmdData, stage2, stage3, stage4, cleanup,
                                             completionMsgSize, completionMsgData);
     return 0;
 }
 
 } /* extern "C" */
 
-namespace nova
-{
+namespace nova {
 
 
-inline void initialize_rate(Rate & rate, double sample_rate, int blocksize)
-{
+inline void initialize_rate(Rate& rate, double sample_rate, int blocksize) {
     rate.mSampleRate = sample_rate;
     rate.mSampleDur = 1. / sample_rate;
     rate.mRadiansPerSample = 2 * boost::math::constants::pi<double>() / sample_rate;
@@ -657,8 +588,7 @@ inline void initialize_rate(Rate & rate, double sample_rate, int blocksize)
 }
 
 
-void sc_plugin_interface::initialize(server_arguments const & args, float * control_busses)
-{
+void sc_plugin_interface::initialize(server_arguments const& args, float* control_busses) {
     const bool nrt_mode = args.non_rt;
 
     done_nodes.reserve(64);
@@ -759,9 +689,9 @@ void sc_plugin_interface::initialize(server_arguments const & args, float * cont
     world.mSndBufs = new SndBuf[world.mNumSndBufs];
     world.mSndBufsNonRealTimeMirror = new SndBuf[world.mNumSndBufs];
     world.mSndBufUpdates = new SndBufUpdates[world.mNumSndBufs];
-    memset(world.mSndBufs, 0, world.mNumSndBufs*sizeof(SndBuf));
-    memset(world.mSndBufsNonRealTimeMirror, 0, world.mNumSndBufs*sizeof(SndBuf));
-    memset(world.mSndBufUpdates, 0, world.mNumSndBufs*sizeof(SndBufUpdates));
+    memset(world.mSndBufs, 0, world.mNumSndBufs * sizeof(SndBuf));
+    memset(world.mSndBufsNonRealTimeMirror, 0, world.mNumSndBufs * sizeof(SndBuf));
+    memset(world.mSndBufUpdates, 0, world.mNumSndBufs * sizeof(SndBufUpdates));
     world.mBufCounter = 0;
 
     async_buffer_guards.reset(new std::mutex[world.mNumSndBufs]);
@@ -771,7 +701,7 @@ void sc_plugin_interface::initialize(server_arguments const & args, float * cont
     world.mSampleRate = args.samplerate;
 
     initialize_rate(world.mFullRate, args.samplerate, args.blocksize);
-    initialize_rate(world.mBufRate, double(args.samplerate)/args.blocksize, 1);
+    initialize_rate(world.mBufRate, double(args.samplerate) / args.blocksize, 1);
 
     world.mNumInputs = args.input_channels;
     world.mNumOutputs = args.output_channels;
@@ -797,44 +727,41 @@ void sc_plugin_interface::initialize(server_arguments const & args, float * cont
         seq.generate(seeds.begin(), seeds.end());
     }
 
-    for (int i=0; i<world.mNumRGens; ++i)
+    for (int i = 0; i < world.mNumRGens; ++i)
         world.mRGen[i].init(seeds[i]);
 }
 
-void sc_plugin_interface::reset_sampling_rate(int sr)
-{
+void sc_plugin_interface::reset_sampling_rate(int sr) {
     world.mSampleRate = sr;
 
     initialize_rate(world.mFullRate, sr, world.mBufLength);
-    initialize_rate(world.mBufRate, double(sr)/world.mBufLength, 1);
+    initialize_rate(world.mBufRate, double(sr) / world.mBufLength, 1);
 }
 
 
-void sc_done_action_handler::apply_done_actions(void)
-{
-    for (server_node * node : done_nodes)
+void sc_done_action_handler::apply_done_actions(void) {
+    for (server_node* node : done_nodes)
         instance->free_node(node);
     done_nodes.clear();
 
-    for (server_node * node : resume_nodes)
+    for (server_node* node : resume_nodes)
         instance->node_resume(node);
     resume_nodes.clear();
 
-    for (server_node * node : pause_nodes)
+    for (server_node* node : pause_nodes)
         instance->node_pause(node);
     pause_nodes.clear();
 
-    for (abstract_group * group : freeDeep_nodes)
+    for (abstract_group* group : freeDeep_nodes)
         instance->group_free_deep(group);
     freeDeep_nodes.clear();
 
-    for (abstract_group * group : freeAll_nodes)
+    for (abstract_group* group : freeAll_nodes)
         instance->group_free_all(group);
     freeAll_nodes.clear();
 }
 
-sc_plugin_interface::~sc_plugin_interface(void)
-{
+sc_plugin_interface::~sc_plugin_interface(void) {
     delete[] world.mAudioBusTouched;
     delete[] world.mControlBusTouched;
     delete[] world.mSndBufs;
@@ -846,22 +773,17 @@ sc_plugin_interface::~sc_plugin_interface(void)
 
 namespace {
 
-sample * allocate_buffer(size_t samples)
-{
+sample* allocate_buffer(size_t samples) {
     const size_t alloc_size = samples * sizeof(sample);
-    sample * ret = (sample*)calloc_aligned(alloc_size);
+    sample* ret = (sample*)calloc_aligned(alloc_size);
     if (ret)
         mlock(ret, alloc_size);
     return ret;
 }
 
-inline int32 bufmask(int32 x)
-{
-    return (1 << (31 - CLZ(x))) - 1;
-}
+inline int32 bufmask(int32 x) { return (1 << (31 - CLZ(x))) - 1; }
 
-inline void sndbuf_init(SndBuf * buf)
-{
+inline void sndbuf_init(SndBuf* buf) {
     buf->samplerate = 0;
     buf->sampledur = 0;
     buf->data = nullptr;
@@ -875,8 +797,7 @@ inline void sndbuf_init(SndBuf * buf)
     buf->isLocal = false;
 }
 
-inline void sndbuf_copy(SndBuf * dest, const SndBuf * src)
-{
+inline void sndbuf_copy(SndBuf* dest, const SndBuf* src) {
     dest->samplerate = src->samplerate;
     dest->sampledur = src->sampledur;
     dest->data = src->data;
@@ -890,16 +811,15 @@ inline void sndbuf_copy(SndBuf * dest, const SndBuf * src)
     dest->isLocal = src->isLocal;
 }
 
-static inline size_t compute_remaining_samples(size_t frames_per_read, size_t already_read, size_t total_frames)
-{
+static inline size_t compute_remaining_samples(size_t frames_per_read, size_t already_read, size_t total_frames) {
     int remain = frames_per_read;
     if (already_read + frames_per_read > total_frames)
         remain = total_frames - already_read;
     return remain;
 }
 
-void read_channel(SndfileHandle & sf, uint32_t channel_count, const uint32_t * channel_data, uint32 total_frames, sample * data)
-{
+void read_channel(SndfileHandle& sf, uint32_t channel_count, const uint32_t* channel_data, uint32 total_frames,
+                  sample* data) {
     const unsigned int frames_per_read = 1024;
     sized_array<sample> read_frame(sf.channels() * frames_per_read);
 
@@ -933,36 +853,33 @@ void read_channel(SndfileHandle & sf, uint32_t channel_count, const uint32_t * c
 
 } /* namespace */
 
-void sc_plugin_interface::allocate_buffer(SndBuf * buf, uint32_t frames, uint32_t channels, double samplerate)
-{
+void sc_plugin_interface::allocate_buffer(SndBuf* buf, uint32_t frames, uint32_t channels, double samplerate) {
     const uint32_t samples = frames * channels;
     if (samples == 0)
-        throw std::runtime_error( "invalid buffer size" );
+        throw std::runtime_error("invalid buffer size");
 
-    sample * data = nova::allocate_buffer(samples);
+    sample* data = nova::allocate_buffer(samples);
     if (data == nullptr)
-        throw std::runtime_error( "could not allocate memory" );
+        throw std::runtime_error("could not allocate memory");
 
-    buf->data       = data;
-    buf->channels   = channels;
-    buf->frames     = frames;
-    buf->samples    = samples;
-    buf->mask       = bufmask(samples); /* for delay lines */
-    buf->mask1      = buf->mask - 1;    /* for oscillators */
+    buf->data = data;
+    buf->channels = channels;
+    buf->frames = frames;
+    buf->samples = samples;
+    buf->mask = bufmask(samples); /* for delay lines */
+    buf->mask1 = buf->mask - 1; /* for oscillators */
     buf->samplerate = samplerate;
-    buf->sampledur  = 1.0 / samplerate;
-    buf->isLocal    = false;
+    buf->sampledur = 1.0 / samplerate;
+    buf->isLocal = false;
 }
 
-SndBuf * sc_plugin_interface::allocate_buffer(uint32_t index, uint32_t frames, uint32_t channels)
-{
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+SndBuf* sc_plugin_interface::allocate_buffer(uint32_t index, uint32_t frames, uint32_t channels) {
+    SndBuf* buf = World_GetNRTBuf(&world, index);
     allocate_buffer(buf, frames, channels, world.mFullRate.mSampleRate);
     return buf;
 }
 
-void sc_plugin_interface::buffer_read_alloc(uint32_t index, const char * filename, uint32_t start, uint32_t frames)
-{
+void sc_plugin_interface::buffer_read_alloc(uint32_t index, const char* filename, uint32_t start, uint32_t frames) {
     auto f = makeSndfileHandle(filename);
     if (f.rawHandle() == nullptr)
         throw std::runtime_error(f.strError());
@@ -975,7 +892,7 @@ void sc_plugin_interface::buffer_read_alloc(uint32_t index, const char * filenam
     if (frames == 0 || frames > sf_frames - start)
         frames = sf_frames - start;
 
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+    SndBuf* buf = World_GetNRTBuf(&world, index);
     allocate_buffer(buf, frames, f.channels(), f.samplerate());
 
     f.seek(start, SEEK_SET);
@@ -983,10 +900,9 @@ void sc_plugin_interface::buffer_read_alloc(uint32_t index, const char * filenam
 }
 
 
-void sc_plugin_interface::buffer_alloc_read_channels(uint32_t index, const char * filename, uint32_t start,
+void sc_plugin_interface::buffer_alloc_read_channels(uint32_t index, const char* filename, uint32_t start,
                                                      uint32_t frames, uint32_t channel_count,
-                                                     const uint32_t * channel_data)
-{
+                                                     const uint32_t* channel_data) {
     // If no channel argument provided we read all channels.
     if (channel_count == 0) {
         buffer_read_alloc(index, filename, start, frames);
@@ -998,7 +914,7 @@ void sc_plugin_interface::buffer_alloc_read_channels(uint32_t index, const char
         throw std::runtime_error(f.strError());
 
     uint32_t sf_channels = uint32_t(f.channels());
-    const uint32_t * max_chan = std::max_element(channel_data, channel_data + channel_count);
+    const uint32_t* max_chan = std::max_element(channel_data, channel_data + channel_count);
     if (*max_chan >= sf_channels)
         throw std::runtime_error("Channel out of range");
 
@@ -1010,7 +926,7 @@ void sc_plugin_interface::buffer_alloc_read_channels(uint32_t index, const char
     if (frames == 0 || frames > sf_frames - start)
         frames = sf_frames - start;
 
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+    SndBuf* buf = World_GetNRTBuf(&world, index);
     allocate_buffer(buf, frames, channel_count, f.samplerate());
 
     f.seek(start, SEEK_SET);
@@ -1018,10 +934,9 @@ void sc_plugin_interface::buffer_alloc_read_channels(uint32_t index, const char
 }
 
 
-int sc_plugin_interface::buffer_write(uint32_t index, const char * filename, const char * header_format, const char * sample_format,
-                                      uint32_t start, uint32_t frames, bool leave_open)
-{
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+int sc_plugin_interface::buffer_write(uint32_t index, const char* filename, const char* header_format,
+                                      const char* sample_format, uint32_t start, uint32_t frames, bool leave_open) {
+    SndBuf* buf = World_GetNRTBuf(&world, index);
     int format = headerFormatFromString(header_format) | sampleFormatFromString(sample_format);
 
     auto sf = makeSndfileHandle(filename, SFM_WRITE, format, buf->channels, buf->samplerate);
@@ -1044,8 +959,7 @@ int sc_plugin_interface::buffer_write(uint32_t index, const char * filename, con
     return 0;
 }
 
-static void buffer_read_verify(SndfileHandle & sf, size_t min_length, size_t samplerate, bool check_samplerate)
-{
+static void buffer_read_verify(SndfileHandle& sf, size_t min_length, size_t samplerate, bool check_samplerate) {
     if (sf.rawHandle() == nullptr)
         throw std::runtime_error(sf.strError());
     if (sf.frames() < min_length)
@@ -1055,10 +969,9 @@ static void buffer_read_verify(SndfileHandle & sf, size_t min_length, size_t sam
         throw std::runtime_error("sample rate mismatch");
 }
 
-void sc_plugin_interface::buffer_read(uint32_t index, const char * filename, uint32_t start_file, uint32_t frames,
-                                      uint32_t start_buffer, bool leave_open)
-{
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+void sc_plugin_interface::buffer_read(uint32_t index, const char* filename, uint32_t start_file, uint32_t frames,
+                                      uint32_t start_buffer, bool leave_open) {
+    SndBuf* buf = World_GetNRTBuf(&world, index);
 
     if (uint32_t(buf->frames) < start_buffer)
         throw std::runtime_error("buffer already full");
@@ -1074,17 +987,16 @@ void sc_plugin_interface::buffer_read(uint32_t index, const char * filename, uin
     const uint32_t frames_to_read = std::min(frames, std::min(buffer_remain, file_remain));
 
     sf.seek(start_file, SEEK_SET);
-    sf.readf(buf->data + start_buffer*buf->channels, frames_to_read);
+    sf.readf(buf->data + start_buffer * buf->channels, frames_to_read);
 
     if (leave_open)
         buf->sndfile = sf.takeOwnership();
 }
 
-void sc_plugin_interface::buffer_read_channel(uint32_t index, const char * filename, uint32_t start_file, uint32_t frames,
-                                             uint32_t start_buffer, bool leave_open, uint32_t channel_count,
-                                             const uint32_t * channel_data)
-{
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+void sc_plugin_interface::buffer_read_channel(uint32_t index, const char* filename, uint32_t start_file,
+                                              uint32_t frames, uint32_t start_buffer, bool leave_open,
+                                              uint32_t channel_count, const uint32_t* channel_data) {
+    SndBuf* buf = World_GetNRTBuf(&world, index);
 
     if (channel_count != uint32_t(buf->channels))
         throw std::runtime_error("channel count mismatch");
@@ -1096,7 +1008,7 @@ void sc_plugin_interface::buffer_read_channel(uint32_t index, const char * filen
     buffer_read_verify(sf, start_file, buf->samplerate, !leave_open);
 
     uint32_t sf_channels = uint32_t(sf.channels());
-    const uint32_t * max_chan = std::max_element(channel_data, channel_data + channel_count);
+    const uint32_t* max_chan = std::max_element(channel_data, channel_data + channel_count);
     if (*max_chan >= sf_channels)
         throw std::runtime_error("channel count mismatch");
 
@@ -1112,9 +1024,8 @@ void sc_plugin_interface::buffer_read_channel(uint32_t index, const char * filen
         buf->sndfile = sf.takeOwnership();
 }
 
-void sc_plugin_interface::buffer_close(uint32_t index)
-{
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+void sc_plugin_interface::buffer_close(uint32_t index) {
+    SndBuf* buf = World_GetNRTBuf(&world, index);
 
     if (buf->sndfile == nullptr)
         return;
@@ -1123,9 +1034,8 @@ void sc_plugin_interface::buffer_close(uint32_t index)
 }
 
 
-void sc_plugin_interface::buffer_zero(uint32_t index)
-{
-    SndBuf * buf = World_GetNRTBuf(&world, index);
+void sc_plugin_interface::buffer_zero(uint32_t index) {
+    SndBuf* buf = World_GetNRTBuf(&world, index);
 
     uint32_t length = buf->frames * buf->channels;
 
@@ -1136,20 +1046,17 @@ void sc_plugin_interface::buffer_zero(uint32_t index)
     zerovec(buf->data + unrolled, remain);
 }
 
-sample * sc_plugin_interface::buffer_generate(uint32_t buffer_index, const char* cmd_name, struct sc_msg_iter & msg)
-{
+sample* sc_plugin_interface::buffer_generate(uint32_t buffer_index, const char* cmd_name, struct sc_msg_iter& msg) {
     return sc_factory->run_bufgen(&world, cmd_name, buffer_index, &msg);
 }
 
-void sc_plugin_interface::buffer_sync(uint32_t index) noexcept
-{
+void sc_plugin_interface::buffer_sync(uint32_t index) noexcept {
     sndbuf_copy(world.mSndBufs + index, world.mSndBufsNonRealTimeMirror + index);
     increment_write_updates(index);
 }
 
-void sc_plugin_interface::free_buffer(uint32_t index)
-{
-    SndBuf * buf = world.mSndBufsNonRealTimeMirror + index;
+void sc_plugin_interface::free_buffer(uint32_t index) {
+    SndBuf* buf = world.mSndBufsNonRealTimeMirror + index;
     if (buf->sndfile)
         sf_close(buf->sndfile);
 
